pub struct IcServer {}Expand description
The Server interface struct for IntelCache. It will listen on port 64209 for new clients.
Then for each client, it will create a new thread for the client,
process and return
IcPackets to the handled client.
Note: to initialize the server the struct must be defined as a global.
Implementations